@@ -2,12 +2,12 @@
 #include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
-#include <QDate>
 #include <QDir>
 
 #include <KI18n/KLocalizedString>
 
 #include <MauiKit3/Core/mauiapp.h>
+#include <MauiKit3/TextEditor/moduleinfo.h>
 
 #ifdef Q_OS_ANDROID
 #include <QGuiApplication>
@@ -50,7 +50,13 @@ int Q_DECL_EXPORT main(int argc, char *argv[])
     app.setWindowIcon(QIcon(":/buho.png"));
 
     KLocalizedString::setApplicationDomain("buho");
-    KAboutData about(QStringLiteral("buho"), i18n("Buho"), BUHO_VERSION_STRING, i18n("Create and organize your notes."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+    KAboutData about(QStringLiteral("buho"),
+                     i18n("Buho"),
+                     BUHO_VERSION_STRING,
+                     i18n("Create and organize your notes."),
+                     KAboutLicense::LGPL_V3, i18n("© 2019-2023 Maui Development Team"),
+                     QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.setHomepage("https://mauikit.org");
     about.setProductName("maui/buho");
@@ -58,8 +64,11 @@ int Q_DECL_EXPORT main(int argc, char *argv[])
     about.setOrganizationDomain(BUHO_URI);
     about.setProgramLogo(app.windowIcon());
 
+    const auto FBData = MauiKitTextEditor::aboutData();
+    about.addComponent(FBData.name(), MauiKitTextEditor::buildVersion(), FBData.version(), FBData.webAddress());
+
     KAboutData::setApplicationData(about);
-    MauiApp::instance()->setIconName("qrc:/buho.png");
+    MauiApp::instance()->setIconName("qrc:/buho.svg");
 
     QCommandLineOption newNoteOption(QStringList() << "n" << "new", "Create a new note.");
     QCommandLineOption newNoteContent(QStringList() << "c" << "content", "new note contents.", "content");
@@ -74,14 +83,11 @@ int Q_DECL_EXPORT main(int argc, char *argv[])
 
     about.processCommandLine(&parser);
 
-
-
     bool newNote = parser.isSet(newNoteOption);
     QString noteContent;
 
 #if (defined Q_OS_LINUX || defined Q_OS_FREEBSD) && !defined Q_OS_ANDROID
 
-
     if(newNote)
     {
         if(parser.isSet(newNoteContent))
